summaryrefslogtreecommitdiff
path: root/sw/source/ui/inc/drawbase.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/ui/inc/drawbase.hxx')
-rw-r--r--sw/source/ui/inc/drawbase.hxx26
1 files changed, 13 insertions, 13 deletions
diff --git a/sw/source/ui/inc/drawbase.hxx b/sw/source/ui/inc/drawbase.hxx
index fa306a080db1..ebcd7fed227c 100644
--- a/sw/source/ui/inc/drawbase.hxx
+++ b/sw/source/ui/inc/drawbase.hxx
@@ -52,9 +52,9 @@ protected:
SwEditWin* m_pWin;
Point m_aStartPos; // Position von BeginCreate
Point m_aMDPos; // Position von MouseButtonDown
- USHORT m_nSlotId;
- BOOL m_bCreateObj :1;
- BOOL m_bInsForm :1;
+ sal_uInt16 m_nSlotId;
+ sal_Bool m_bCreateObj :1;
+ sal_Bool m_bInsForm :1;
Point GetDefaultCenterPos();
public:
@@ -63,20 +63,20 @@ public:
void SetDrawPointer();
void EnterSelectMode(const MouseEvent& rMEvt);
- inline BOOL IsInsertForm() const { return m_bInsForm; }
- inline BOOL IsCreateObj() const { return m_bCreateObj; }
+ inline sal_Bool IsInsertForm() const { return m_bInsForm; }
+ inline sal_Bool IsCreateObj() const { return m_bCreateObj; }
- // Mouse- & Key-Events; Returnwert=TRUE: Event wurde bearbeitet
- virtual BOOL KeyInput(const KeyEvent& rKEvt);
- virtual BOOL MouseMove(const MouseEvent& rMEvt);
- virtual BOOL MouseButtonUp(const MouseEvent& rMEvt);
- virtual BOOL MouseButtonDown(const MouseEvent& rMEvt);
+ // Mouse- & Key-Events; Returnwert=sal_True: Event wurde bearbeitet
+ virtual sal_Bool KeyInput(const KeyEvent& rKEvt);
+ virtual sal_Bool MouseMove(const MouseEvent& rMEvt);
+ virtual sal_Bool MouseButtonUp(const MouseEvent& rMEvt);
+ virtual sal_Bool MouseButtonDown(const MouseEvent& rMEvt);
void BreakCreate();
- void SetSlotId(USHORT nSlot) {m_nSlotId = nSlot;}
- USHORT GetSlotId() { return m_nSlotId;}
+ void SetSlotId(sal_uInt16 nSlot) {m_nSlotId = nSlot;}
+ sal_uInt16 GetSlotId() { return m_nSlotId;}
- virtual void Activate(const USHORT nSlotId); // Function aktivieren
+ virtual void Activate(const sal_uInt16 nSlotId); // Function aktivieren
virtual void Deactivate(); // Function deaktivieren
virtual void CreateDefaultObject();